@@ -609,9 +609,6 @@ class RegisterEventWizardView(SessionWizardView):
             _email.person = person
             _email.save()
 
-        # Add the current person to the event
-        event.linked_group.members.add(person)
-
         registration = EventRegistration.objects.create(
             event=event,
             person=person,
